@@ -1,15 +1,18 @@
 def someFunction(user, password="Admin"):
-    print "Hi " + user
+    print("Hi " + user)
 
 def someFunction2(password):
     if password == "root":
-        print "OK, logged in"
+        print("OK, logged in")
 
 def noMatch(password):
     if password == '':
-        print "No password!"
+        print("No password!")
 
 def NoMatch2(password):
     if password == "ajklawejrkl42348swfgkg":
-        print "Nice password!"
+        print("Nice password!")
 
+doLogin(password="blerg")
+password = "blerg"
+d["password"] = "blerg"
