@@ -21,6 +21,7 @@ import bandit
 from bandit.core import constants
 from bandit.core import config
 from bandit.core import manager
+from bandit.core import metrics
 from bandit.core import issue
 from bandit.formatters import text as b_text
 
@@ -46,14 +47,14 @@ class TextFormatterTests(testtools.TestCase):
         self.issue.test = self.check_name
 
         self.manager.results.append(self.issue)
+        self.manager.metrics = metrics.Metrics()
 
         #mock up the metrics
-        self.manager.metrics = {}
         for key in ['_totals', 'binding.py']:
-            self.manager.metrics[key] = {'loc':4, 'nosec':2}
+            self.manager.metrics.data[key] = {'loc':4, 'nosec':2}
             for (criteria, default) in constants.CRITERIA:
                 for rank in constants.RANKING:
-                    self.manager.metrics[key]['{0}.{1}'.format(
+                    self.manager.metrics.data[key]['{0}.{1}'.format(
                         criteria, rank
                     )] = 0
 
@@ -69,7 +70,7 @@ class TextFormatterTests(testtools.TestCase):
 
         with open(self.tmp_fname) as f:
             data = f.read()
-            expected = '>> Issue: %s' % self.issue.text
+            expected = '>> Issue: [%s] %s' % (self.issue.test, self.issue.text)
             self.assertIn(expected, data)
             expected = '   Severity: %s   Confidence: %s' % (
                 self.issue.severity.capitalize(),
@@ -79,10 +80,10 @@ class TextFormatterTests(testtools.TestCase):
                                                self.context['lineno'])
             self.assertIn(expected, data)
             expected = 'Total lines of code: {0}'.format(
-                self.manager.metrics['_totals']['loc']
+                self.manager.metrics.data['_totals']['loc']
             )
             self.assertIn(expected, data)
             expected = 'Total lines skipped (#nosec): {0}'.format(
-                self.manager.metrics['_totals']['nosec']
+                self.manager.metrics.data['_totals']['nosec']
             )
             self.assertIn(expected, data)
